@@ -14,8 +14,8 @@ class TimestampType(Enum):
     """
     时间戳类型：枚举
     """
-    SECONDS = 0 # 秒
-    MILLISECOND = 1 # 毫秒
+    SECONDS = 0  # 秒
+    MILLISECOND = 1  # 毫秒
 
 
 class DateTimeTool(object):
@@ -86,3 +86,26 @@ class DateTimeTool(object):
             return [ts_begin, ts_end]
         else:
             return [ts_begin * 1000, ts_end * 1000 + 999]
+
+    @staticmethod
+    def get_difference_between_time(time1, time2, formatter: str='%Y-%m-%d %H:%M:%S', tsType: TimestampType=TimestampType.SECONDS) -> int:
+        """
+        返回给定的两个时间的差值
+        @param time1: 第一个时间，可以为时间戳形式或时间字符串形式
+        @param time2: 第二个时间，可以为时间戳形式或时间字符串形式
+        @param formatter: 若给定的两个时间为字符串形式，则该参数生效
+        @param tsType: 返回的时间差单位：秒或毫秒
+        @return:
+        """
+        if type(time1) == str:
+            time1 = DateTimeTool.time2timestamp(time1, formatter=formatter, tsType=tsType)
+
+        if type(time2) == str:
+            time2 = DateTimeTool.time2timestamp(time2, formatter=formatter, tsType=tsType)
+
+        return abs(time1 - time2)
+
+
+if __name__ == '__main__':
+    print(DateTimeTool.time2timestamp('2024-02-20 08:30:00', tsType=TimestampType.MILLISECOND))
+    print(DateTimeTool.get_difference_between_time(1708389000000, '2024-02-20 08:31:30', tsType=TimestampType.MILLISECOND))
